/// <reference types="node" />
import TypedEmitter from 'typed-emitter';
import * as protocol from './protocol';
declare type PacketHandlerEvents = {
    [key in keyof typeof protocol]: (packet: InstanceType<typeof protocol[key]>) => void;
};
declare const PacketHandler_base: new () => TypedEmitter<PacketHandlerEvents>;
/**
 * Instantiate a new PacketHandler class.
 * This class extends EventEmitter and for
 * each successfuly handled packet the event
 * emitter will emit an event. If a `CooldownPacket`
 * is received, an event with name `CooldownPacket`
 * is emitted.
 *
 * @example
 * ```javascript
 * const packetHandler = new PacketHandler();
 *
 * // Call PacketHandler#handle with
 * // the buffer everytime you receive
 * // a packet
 *
 * packetHandler.on('CooldownPacket', ({ data }) => {
 *   // Do something with data
 * });
 * ```
 */
export default class PacketHandler extends PacketHandler_base {
    /**
     * Handle a packet, if everything is successful
     * an event will be emited with the content of
     * the packet
     */
    handle(buffer: Buffer): void;
}
export {};
