"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LunarMod = exports.MiniMapStatus = exports.ServerRuleEnum = exports.NotificationLevel = exports.VoiceChannelUpdateStatus = exports.PluginChannel = void 0;
/**
 * Plugin channels Lunar Client uses
 * to establish the connection between
 * the client and the server
 */
var PluginChannel;
(function (PluginChannel) {
    /**
     * New plugin channel, recommended
     *
     * Value: `lunarclient:pm`
     */
    PluginChannel["NEW"] = "lunarclient:pm";
    /**
     * Old plugin channel, shouldn't be
     * used today but the connection seems
     * to be established anyway.
     *
     * Value: `Lunar-Client`
     * @deprecated
     */
    PluginChannel["OLD"] = "Lunar-Client";
})(PluginChannel = exports.PluginChannel || (exports.PluginChannel = {}));
/**
 * Status code used by the VoiceChannelUpdatePacket
 */
var VoiceChannelUpdateStatus;
(function (VoiceChannelUpdateStatus) {
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_ADD"] = 0] = "PLAYER_ADD";
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_REMOVE"] = 1] = "PLAYER_REMOVE";
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_LISTENING"] = 2] = "PLAYER_LISTENING";
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_DEAFENED"] = 3] = "PLAYER_DEAFENED";
})(VoiceChannelUpdateStatus = exports.VoiceChannelUpdateStatus || (exports.VoiceChannelUpdateStatus = {}));
/**
 * Different level the notification could be
 */
var NotificationLevel;
(function (NotificationLevel) {
    NotificationLevel["INFO"] = "info";
    NotificationLevel["SUCCESS"] = "success";
    NotificationLevel["WARNING"] = "warning";
    NotificationLevel["ERROR"] = "error";
})(NotificationLevel = exports.NotificationLevel || (exports.NotificationLevel = {}));
/**
 * List of all server rules
 * @see https://github.com/LunarClient/BukkitAPI-NetHandler/blob/master/src/main/java/com/lunarclient/bukkitapi/nethandler/client/obj/ServerRule.java
 */
var ServerRuleEnum;
(function (ServerRuleEnum) {
    /**
     * Whether or not minimap is allowed.
     * Expected value: (String) `NEUTRAL` or `FORCED_OFF`
     */
    ServerRuleEnum["MINIMAP_STATUS"] = "minimapStatus";
    /**
     * Whether or not the server will store waypoints, instead of the client
     */
    ServerRuleEnum["SERVER_HANDLES_WAYPOINTS"] = "serverHandlesWaypoints";
    /**
     * A warning message will be shown when attempting to disconnect if the current
     * game is competitive.
     */
    ServerRuleEnum["COMPETITIVE_GAME"] = "competitiveGame";
    /**
     * If this server forces shaders to be disabled
     */
    ServerRuleEnum["SHADERS_DISABLED"] = "shadersDisabled";
    /**
     * If the server runs legacy enchanting (pre 1.8)
     */
    ServerRuleEnum["LEGACY_ENCHANTING"] = "legacyEnchanting";
    /**
     * If this server has enabled voice chat
     */
    ServerRuleEnum["VOICE_ENABLED"] = "voiceEnabled";
    /**
     * Whether to revert combat mechanics to 1.7
     */
    ServerRuleEnum["LEGACY_COMBAT"] = "legacyCombat";
})(ServerRuleEnum = exports.ServerRuleEnum || (exports.ServerRuleEnum = {}));
/**
 * MinimapStatus values for the server rule
 */
var MiniMapStatus;
(function (MiniMapStatus) {
    MiniMapStatus["NEUTRAL"] = "NEUTRAL";
    MiniMapStatus["FORCED_OFF"] = "FORCED_OFF";
})(MiniMapStatus = exports.MiniMapStatus || (exports.MiniMapStatus = {}));
/**
 * List of all Lunar Client mods
 *
 * Some of them are not present anymore be careful!
 */
var LunarMod;
(function (LunarMod) {
    LunarMod["TIME_CHANGER"] = "time_changer";
    LunarMod["NEU"] = "neu";
    LunarMod["NAMETAG"] = "nametag";
    LunarMod["SHINY_POTS"] = "shinyPots";
    LunarMod["BLOCK_OUTLINE"] = "block_outline";
    LunarMod["HYPIXEL_MOD"] = "hypixel_mod";
    LunarMod["RANGE"] = "range";
    LunarMod["REPLAYMOD"] = "replaymod";
    LunarMod["RECORDING_INDICATOR"] = "recording_indicator";
    LunarMod["PARTICLE_MOD"] = "particleMod";
    LunarMod["FOV_MOD"] = "fov_mod";
    LunarMod["MOMENTUM_MOD"] = "momentum_mod";
    LunarMod["SCREENSHOT"] = "screenshot";
    LunarMod["LIGHTING"] = "lighting";
    LunarMod["ARMORSTATUS"] = "armorstatus";
    LunarMod["ITEM_PHYSIC"] = "itemPhysic";
    LunarMod["PACK_ORGANIZER"] = "pack_organizer";
    LunarMod["STAFF_XRAY"] = "staff.XRAY";
    LunarMod["TITLE_MOD"] = "titleMod";
    LunarMod["FPS"] = "fps";
    LunarMod["TAB"] = "tab";
    LunarMod["COOLDOWNS"] = "cooldowns";
    LunarMod["CROSSHAIR"] = "crosshair";
    LunarMod["CHAT"] = "chat";
    LunarMod["HYPIXEL_BEDWARS"] = "hypixel_bedwars";
    LunarMod["COMBO"] = "combo";
    LunarMod["SOUND_CHANGER"] = "sound_changer";
    LunarMod["SCOREBOARD"] = "scoreboard";
    LunarMod["STOPWATCH"] = "stopwatch";
    LunarMod["HITBOX"] = "hitbox";
    LunarMod["KEYSTROKES"] = "keystrokes";
    LunarMod["SATURATION_MOD"] = "saturation_mod";
    LunarMod["SATURATION_HUD_MOD"] = "saturation_hud_mod";
    LunarMod["HIT_COLOR"] = "hitColor";
    LunarMod["SNAPLOOK"] = "snaplook";
    LunarMod["MUMBLE_LINK"] = "mumble-link";
    LunarMod["BOSSBAR"] = "bossbar";
    LunarMod["FREELOOK"] = "freelook";
    LunarMod["SCROLLABLE_TOOLTIPS"] = "scrollable_tooltips";
    LunarMod["ITEMS2D"] = "items2d";
    LunarMod["DAYCOUNTER"] = "daycounter";
    LunarMod["SKIN_LAYERS3_D"] = "skinLayers3D";
    LunarMod["WEATHER_CHANGER"] = "weather_changer";
    LunarMod["CPS"] = "cps";
    LunarMod["CLOCK"] = "clock";
    LunarMod["TOGGLE_SNEAK"] = "toggleSneak";
    LunarMod["MENU_BLUR"] = "menu_blur";
    LunarMod["DIRECTIONHUD"] = "directionhud";
    LunarMod["TEAMVIEW"] = "teamview";
    LunarMod["COORDS"] = "coords";
    LunarMod["NICK_HIDER"] = "nickHider";
    LunarMod["COLORSATURATION"] = "colorsaturation";
    LunarMod["CHUNKBORDERS"] = "chunkborders";
    LunarMod["RESOURCE_DISPLAY"] = "resource_display";
    LunarMod["SKYBLOCK_ADDONS"] = "skyblockAddons";
    LunarMod["QUICKPLAY"] = "quickplay";
    LunarMod["TEXT_HOT_KEY"] = "textHotKey";
    LunarMod["POTIONEFFECTS"] = "potioneffects";
    LunarMod["TNT_COUNTDOWN"] = "tntCountdown";
    LunarMod["MOTION_BLUR"] = "motionBlur";
    LunarMod["ZOOM"] = "zoom";
    LunarMod["WAYPOINTS"] = "waypoints";
    LunarMod["PING"] = "ping";
    LunarMod["WORLDEDIT_CUI"] = "worldedit_cui";
    LunarMod["SERVER_ADDRESS_MOD"] = "serverAddressMod";
    LunarMod["MEMORY"] = "memory";
    LunarMod["GLINT_COLORIZER"] = "glint_colorizer";
    LunarMod["PANORAMA_MAKER"] = "panorama_maker";
    LunarMod["ITEM_TRACKER_CHILD"] = "itemTrackerChild";
    LunarMod["UHC_OVERLAY"] = "uhc_overlay";
    LunarMod["HOLOGRAMS"] = "holograms";
    LunarMod["BORDERS"] = "borders";
    LunarMod["CUSTOM_NAMEPLATE"] = "custom_nameplate";
    LunarMod["COMP_WARN"] = "comp_warn";
    LunarMod["VOICE"] = "voice";
    LunarMod["TITLES"] = "titles";
})(LunarMod = exports.LunarMod || (exports.LunarMod = {}));
